import typer

from wet_net.scripts.evaluate import evaluate
from wet_net.scripts.pre_process import pre_process
from wet_net.scripts.train import train

app = typer.Typer()

app.command(name="pre-process")(pre_process)
app.command(name="train")(train)
app.command(name="evaluate")(evaluate)

if __name__ == "__main__":
    app()



import time

import typer

app = typer.Typer()


@app.command()
def pre_process(dry_run: bool = typer.Option(False, help="Dry run the pre-processing.")):
    """
    Pre-process data (dummy implementation).
    """
    typer.echo("Pre-processing started...")
    if not dry_run:
        with typer.progressbar(range(100), label="Pre-processing") as progress:
            for _ in progress:
                time.sleep(0.01)
    typer.echo("Pre-processing completed.")


if __name__ == "__main__":
    app()
